@@ -1,6 +1,6 @@
 /* 1.cpp:
 
-   Copyright (C) 1996-2020 Christian Schenk
+   Copyright (C) 1996-2021 Christian Schenk
 
    This file is part of the MiKTeX Core Library.
 
@@ -29,10 +29,11 @@
 #include <miktex/Core/Directory>
 #include <miktex/Core/File>
 #include <miktex/Core/Fndb>
-#include <miktex/Core/PathName>
 #include <miktex/Core/Paths>
+#include <miktex/Util/PathName>
 #include <miktex/Util/StringUtil>
 
+using namespace MiKTeX::Configuration;
 using namespace MiKTeX::Core;
 using namespace MiKTeX::Test;
 using namespace MiKTeX::Util;
