@@ -300,14 +300,9 @@ inline int miktexgetsynchronizationoptions()
   return TeXApp::GetTeXApp()->GetSynchronizationOptions();
 }
 
-inline bool restrictedshell()
+inline bool miktexsourcespecialsp()
 {
-  return TeXApp::GetTeXApp()->GetWrite18Mode() == MiKTeX::Core::ShellCommandMode::Restricted || TeXApp::GetTeXApp()->GetWrite18Mode() == MiKTeX::Core::ShellCommandMode::Query;
-}
-
-inline bool shellenabledp()
-{
-  return miktexwrite18p();
+  return TeXApp::GetTeXApp()->SourceSpecialsP();
 }
 
 inline bool miktexiscompatible()
@@ -315,6 +310,24 @@ inline bool miktexiscompatible()
   return !TeXApp::GetTeXApp()->SourceSpecialsP() && !TeXApp::GetTeXApp()->CStyleErrorMessagesP() && !TeXApp::GetTeXApp()->ParseFirstLineP();
 }
 
+// web2c shim
+inline bool restrictedshell()
+{
+  return TeXApp::GetTeXApp()->GetWrite18Mode() == MiKTeX::Core::ShellCommandMode::Restricted || TeXApp::GetTeXApp()->GetWrite18Mode() == MiKTeX::Core::ShellCommandMode::Query;
+}
+
+// web2c shim
+inline bool shellenabledp()
+{
+  return miktexwrite18p();
+}
+
+// web2c shim
+inline bool srcspecialsp()
+{
+  return TeXApp::GetTeXApp()->SourceSpecialsP();
+}
+
 MIKTEX_TEXMF_END_NAMESPACE;
 
 #endif
