@@ -894,9 +894,9 @@ void TeXMFApp::InitializeBuffer() const
     }
   }
 
-  //MIKTEX_ASSERT(inout->first() == 1);
   C4P::C4P_signed32& last = inout->last();
-  last = 1;
+  auto first = inout->first();
+  last = first;
   char32_t* buffer32 = AmI("xetex") ? inout->buffer32() : nullptr;
   char*buffer = !IsUnicodeApp() ? inout->buffer() : nullptr;
   for (int idx = 1; idx < argc; ++idx)
@@ -937,6 +937,29 @@ void TeXMFApp::InitializeBuffer() const
     }
   }
 
+  if (AmI("xetex"))
+  {
+    for (last--; last >= first && (buffer32[last] == U' ' || buffer32[last] == U'\r' || buffer32[last] == U'\n'); last++)
+    {
+    }
+  }
+  else
+  {
+    for (last--; last >= first && (buffer[last] == ' ' || buffer[last] == '\r' || buffer[last] == '\n'); last++)
+    {
+    }
+  }
+  last++;
+
+  if (!AmI("xetex"))
+  {
+    const char* xord = GetCharacterConverter()->xord();
+    for (int i = first; i < last; i++)
+    {
+      buffer[i] = xord[buffer[i]&0xff];
+    }
+  }
+
   // clear the command-line
   GetProgram()->MakeCommandLine(vector<string>());
 }
@@ -944,8 +967,7 @@ void TeXMFApp::InitializeBuffer() const
 void TeXMFApp::TouchJobOutputFile(FILE* file) const
 {
   MIKTEX_ASSERT(file != nullptr);
-  shared_ptr<Session> session = GetSession();
-  if (pimpl->setJobTime && session->IsOutputFile(file))
+  if (pimpl->setJobTime)
   {
     time_t time = GetProgram()->GetStartUpTime();
     File::SetTimes(file, time, time, time);
