@@ -154,7 +154,7 @@ residentfont(register fontdesctype *curfnt)
    if (p->Fontfile && downloadpspk) {
 #ifdef DEBUG
       if (dd(D_FONTS))
-         fprintf(stderr,"Using PK font %s for <%s>.\n",
+         fprintf_str(stderr,"Using PK font %s for <%s>.\n",
                                      curfnt->name, p->PSname);
 #endif  /* DEBUG */
       return 0;
@@ -164,7 +164,7 @@ residentfont(register fontdesctype *curfnt)
  */
 #ifdef DEBUG
    if (dd(D_FONTS))
-        fprintf(stderr,"Font %s <%s> is resident.\n",
+        fprintf_str(stderr,"Font %s <%s> is resident.\n",
                                      curfnt->name, p->PSname);
 #endif  /* DEBUG */
    curfnt->resfont = p;
@@ -220,9 +220,9 @@ static unsigned c_lineno;
 static void
 bad_config(const char *err)
 {
-   fprintf (stderr, "%s:%d:", realnameoffile, c_lineno);
+   fprintf_str(stderr, "%s:%d:", realnameoffile, c_lineno);
    error (err);
-   fprintf(stderr, " (%s)\n", was_inline);
+   fprintf_str(stderr, " (%s)\n", was_inline);
 }
 
 #ifndef KPATHSEA
@@ -395,12 +395,12 @@ getdefaults(const char *s)
          fprintf(stderr, "\n");
          prettycolumn = 0;
       }
-      fprintf(stderr, "{%s}", realnameoffile);
+      fprintf_str(stderr, "{%s}", realnameoffile);
       prettycolumn += strlen(realnameoffile) + 2;
    }
 #ifdef DEBUG
      if (dd (D_CONFIG)) {
-       fprintf (stderr, "Reading dvips config file `%s':\n", realnameoffile);
+       fprintf_str(stderr, "Reading dvips config file `%s':\n", realnameoffile);
      }
 #endif
      c_lineno = 0;
@@ -408,7 +408,7 @@ getdefaults(const char *s)
        c_lineno++;
 #ifdef DEBUG
        if (dd (D_CONFIG)) {
-         fprintf (stderr, "%s:%d:%s", realnameoffile, c_lineno, was_inline);
+         fprintf_str(stderr, "%s:%d:%s", realnameoffile, c_lineno, was_inline);
        }
 #endif
 /*
@@ -746,7 +746,7 @@ case 'e' :
          break;
 case 'z' :
 	 if (secure_option && secure && was_inline[1] == '0') {
-	   fprintf (stderr,
+	   fprintf_str(stderr,
 	            "warning: %s: z0 directive ignored since -R1 given\n",
 	            realnameoffile); /* Never happen */
          } else {
@@ -863,7 +863,7 @@ getpsinfo(const char *name)
             fprintf(stderr, "\n");
             prettycolumn = 0;
          }
-         fprintf(stderr, "{%s}", realnameoffile);
+         fprintf_str(stderr, "{%s}", realnameoffile);
          prettycolumn += strlen(realnameoffile) + 2;
       }
       while (fgets(was_inline, INLINE_SIZE, deffile)!=NULL) {
