@@ -1430,6 +1430,8 @@ vector<FileLink> miktexFileLinks =
   { MIKTEX_DVITYPE_EXE, { "dvitype" } },
   { MIKTEX_EPSFFIT_EXE, { "epsffit" } },
   { MIKTEX_EPSTOPDF_EXE,{ "epstopdf", "repstopdf", MIKTEX_PREFIX "epstopdf-unrestricted" } },
+  { MIKTEX_EPTEX_EXE, { "eptex" } },
+  { MIKTEX_EUPTEX_EXE, { "euptex" } },
   { MIKTEX_EXTCONV_EXE, { "extconv" } },
   { MIKTEX_FRIBIDIXETEX_EXE, { "fribidixetex" } },
   { MIKTEX_GFTODVI_EXE, { "gftodvi" } },
@@ -1455,12 +1457,15 @@ vector<FileLink> miktexFileLinks =
   { MIKTEX_OVF2OVP_EXE, { "ovf2ovp" } },
   { MIKTEX_OVP2OVF_EXE, { "ovp2ovf" } },
   { MIKTEX_PREFIX "patgen" MIKTEX_EXE_FILE_SUFFIX, { "patgen"} },
+  { MIKTEX_PBIBTEX_EXE, { "pbibtex" } },
   { MIKTEX_PDFTEX_EXE, { "pdftex", MIKTEX_LATEX_EXE, MIKTEX_PDFLATEX_EXE } },
   { MIKTEX_PDFTOSRC_EXE, { "pdftosrc" } },
+  { MIKTEX_PDVITYPE_EXE, { "pdvitype" } },
   { MIKTEX_PK2BM_EXE, { "pk2bm" } },
   { MIKTEX_PLTOTF_EXE, { "pltotf" } },
   { MIKTEX_PMXAB_EXE, { "pmxab" } },
   { MIKTEX_POOLTYPE_EXE, { "pooltype" } },
+  { MIKTEX_PPLTOTF_EXE, { "ppltotf" } },
   { MIKTEX_PREPMX_EXE, { "prepmx" } },
   { MIKTEX_PS2PK_EXE, { "ps2pk" } },
   { MIKTEX_PSBOOK_EXE, { "psbook" } },
@@ -1468,6 +1473,8 @@ vector<FileLink> miktexFileLinks =
   { MIKTEX_PSRESIZE_EXE, { "psresize" } },
   { MIKTEX_PSSELECT_EXE, { "psselect" } },
   { MIKTEX_PSTOPS_EXE, { "pstops" } },
+  { MIKTEX_PTEX_EXE, { "ptex" } },
+  { MIKTEX_PTFTOPL_EXE, { "ptftopl" } },
   { MIKTEX_REBAR_EXE, { "rebar" } },
   { MIKTEX_SCOR2PRT_EXE, { "scor2prt" } },
   { MIKTEX_SJISCONV_EXE, { "sjisconv" } },
@@ -1484,6 +1491,11 @@ vector<FileLink> miktexFileLinks =
   { MIKTEX_TTF2AFM_EXE, { "ttf2afm" } },
   { MIKTEX_TTF2PK_EXE, { "ttf2pk" } },
   { MIKTEX_TTF2TFM_EXE, { "ttf2tfm" } },
+  { MIKTEX_UPBIBTEX_EXE, { "upbibtex" } },
+  { MIKTEX_UPDVITYPE_EXE, { "updvitype" } },
+  { MIKTEX_UPPLTOTF_EXE, { "uppltotf" } },
+  { MIKTEX_UPTEX_EXE, { "uptex" } },
+  { MIKTEX_UPTFTOPL_EXE, { "uptftopl" } },
   { MIKTEX_PREFIX "upmendex" MIKTEX_EXE_FILE_SUFFIX, { "upmendex"} },
   { MIKTEX_VFTOVP_EXE, { "vftovp" } },
   { MIKTEX_VPTOVF_EXE, { "vptovf" } },
@@ -1498,6 +1510,7 @@ vector<FileLink> miktexFileLinks =
 #endif
 #if defined(MIKTEX_MACOS_BUNDLE)
   { MIKTEX_INITEXMF_EXE, { MIKTEX_INITEXMF_EXE }},
+  { MIKTEX_MIKTEX_EXE, { MIKTEX_MIKTEX_EXE }},
   { MIKTEX_MPM_EXE, { MIKTEX_MPM_EXE } },
   { MIKTEX_TEXIFY_EXE, { MIKTEX_TEXIFY_EXE } },
   { "mthelp" MIKTEX_EXE_FILE_SUFFIX, { "mthelp" MIKTEX_EXE_FILE_SUFFIX } },
