@@ -52,7 +52,11 @@ enum class Engine
 {
   LuaTeX,
   TeX,
+  epTeX,
+  eupTeX,
   pdfTeX,
+  pTeX,
+  upTeX,
   XeTeX,
   LuaHBTeX,
 };
@@ -127,6 +131,22 @@ private:
     {
       this->engine = Engine::pdfTeX;
     }
+    else if (Utils::EqualsIgnoreCase(engine, "ptex"))
+    {
+      this->engine = Engine::pTeX;
+    }
+    else if (Utils::EqualsIgnoreCase(engine, "eptex"))
+    {
+      this->engine = Engine::epTeX;
+    }
+    else if (Utils::EqualsIgnoreCase(engine, "euptex"))
+    {
+      this->engine = Engine::eupTeX;
+    }
+    else if (Utils::EqualsIgnoreCase(engine, "uptex"))
+    {
+      this->engine = Engine::upTeX;
+    }
     else if (Utils::EqualsIgnoreCase(engine, "xetex"))
     {
       this->engine = Engine::XeTeX;
@@ -158,6 +178,14 @@ public:
       return "tex";
     case Engine::pdfTeX:
       return "pdftex";
+    case Engine::pTeX:
+      return "ptex";
+    case Engine::epTeX:
+      return "eptex";
+    case Engine::eupTeX:
+      return "euptex";
+    case Engine::upTeX:
+      return "uptex";
     case Engine::XeTeX:
       return "xetex";
     case Engine::LuaHBTeX:
@@ -177,6 +205,14 @@ private:
       return MIKTEX_TEX_EXE;
     case Engine::pdfTeX:
       return MIKTEX_PDFTEX_EXE;
+    case Engine::pTeX:
+      return MIKTEX_PTEX_EXE;
+    case Engine::epTeX:
+      return MIKTEX_EPTEX_EXE;
+    case Engine::eupTeX:
+      return MIKTEX_EUPTEX_EXE;
+    case Engine::upTeX:
+      return MIKTEX_UPTEX_EXE;
     case Engine::XeTeX:
       return MIKTEX_XETEX_EXE;
     case Engine::LuaHBTeX:
@@ -200,6 +236,8 @@ private:
   bool IsExtended() const
   {
     bool result = engine == Engine::LuaTeX || engine == Engine::pdfTeX || engine == Engine::XeTeX;
+    result = result || engine == Engine::epTeX;
+    result = result || engine == Engine::eupTeX;
     result = result || engine == Engine::LuaHBTeX;
     return result;
   }
