@@ -1,22 +1,24 @@
-/* internal.h:                                          -*- C++ -*-
-
-   Copyright (C) 2002-2021 Christian Schenk
-
-   This file is part of MkFntMap.
-
-   MkFntMap is free software; you can redistribute it and/or modify it
-   under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
-   MkFntMap is distributed in the hope that it will be useful, but
-   WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with MkFntMap; if not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+/**
+ * @file internal.h
+ * @author Christian Schenk
+ * @brief Internal definitions.
+ * 
+ * @copyright Copyright © 2002-2021 Christian Schenk
+ * 
+ * This file is part of MiKTeX Fontmap Maintenance Utility.
+ *
+ * MiKTeX Fontmap Maintenance Utility is licensed under GNU General Public
+ * License version 2 or any later version.
+ *
+ * MiKTeX Fontmap Maintenance Utility is based on the updmap Perl script
+ * (updmap.pl):
+ * 
+ * @code {.unparsed}
+ * # Copyright 2011-2021 Norbert Preining
+ * # This file is licensed under the GNU General Public License version 2
+ * # or any later version.
+ * @endcode
+ */
 
 #include <algorithm>
 #include <fstream>
