@@ -239,7 +239,7 @@ enum class MacroLanguage
 
 enum class Engine
 {
-  NotSet, TeX, pdfTeX, XeTeX, LuaTeX, LuaHBTeX,
+  NotSet, TeX, pdfTeX, pTeX, epTeX, eupTeX, upTeX, XeTeX, LuaTeX, LuaHBTeX
 };
 
 enum class OutputType {
@@ -367,6 +367,18 @@ public:
 public:
   string pdftexProgram;
 
+public:
+  string ptexProgram;
+
+public:
+  string eptexProgram;
+
+public:
+  string euptexProgram;
+
+public:
+  string uptexProgram;
+
 public:
   string xetexProgram;
 
@@ -416,6 +428,22 @@ public:
     {
       engine = Engine::pdfTeX;
     }
+    else if (Utils::EqualsIgnoreCase(engineName, "ptex"))
+    {
+      engine = Engine::pTeX;
+    }
+    else if (Utils::EqualsIgnoreCase(engineName, "eptex"))
+    {
+      engine = Engine::epTeX;
+    }
+    else if (Utils::EqualsIgnoreCase(engineName, "euptex"))
+    {
+      engine = Engine::eupTeX;
+    }
+    else if (Utils::EqualsIgnoreCase(engineName, "uptex"))
+    {
+      engine = Engine::upTeX;
+    }
     else if (Utils::EqualsIgnoreCase(engineName, "xetex"))
     {
       engine = Engine::XeTeX;
@@ -486,6 +514,10 @@ Options::Options()
   makeinfoProgram = SetProgramName("MAKEINFO", "makeinfo");
   pdflatexProgram = SetProgramName("PDFLATEX", "pdflatex");
   pdftexProgram = SetProgramName("PDFTEX", MIKTEX_PDFTEX_EXE);
+  ptexProgram = SetProgramName("PTEX", MIKTEX_PTEX_EXE);
+  eptexProgram = SetProgramName("EPTEX", MIKTEX_EPTEX_EXE);
+  euptexProgram = SetProgramName("EUPTEX", MIKTEX_EUPTEX_EXE);
+  uptexProgram = SetProgramName("UPTEX", MIKTEX_UPTEX_EXE);
   texProgram = SetProgramName("TEX", MIKTEX_TEX_EXE);
   texindexProgram = SetProgramName("TEXINDEX", "texindex");
   xelatexProgram = SetProgramName("XELATEX", "xelatex");
@@ -2043,6 +2075,8 @@ void McdApp::Run(int argc, const char** argv)
 
   int option;
 
+  bool optVersion = false;
+
   while ((option = popt.GetNextOpt()) >= 0)
   {
     string optArg = popt.GetOptArg();
@@ -2117,8 +2151,8 @@ void McdApp::Run(int argc, const char** argv)
       break;
 #endif
     case OPT_VERSION:
-      Version();
-      return;
+      optVersion = true;
+      break;
     case OPT_VERBOSE:
       options.verbose = true;
       break;
@@ -2198,7 +2232,7 @@ void McdApp::Run(int argc, const char** argv)
 
   vector<string> leftovers = popt.GetLeftovers();
 
-  if (leftovers.empty())
+  if (leftovers.empty() && !optVersion)
   {
     FatalError(T_("Missing file argument."));
   }
@@ -2210,6 +2244,12 @@ void McdApp::Run(int argc, const char** argv)
 
   Init(initInfo);
 
+  if (optVersion)
+  {
+    Version();
+    return;
+  }
+
   for (const string& fileName : leftovers)
   {
     Verbose(fmt::format(T_("processing {}..."), Q_(fileName)));
